@@ -633,7 +633,7 @@ class PageObject(DictionaryObject):
             DictionaryObject, res2.get(resource, DictionaryObject()).get_object()
         )
         rename_res = {}
-        for key in page2res.keys():
+        for key in page2res:
             unique_key, same_value = compute_unique_key(key)
             newname = NameObject(unique_key)
             if key != unique_key:
@@ -935,7 +935,11 @@ class PageObject(DictionaryObject):
                 trsf = Transformation(ctm)
             for a in cast(ArrayObject, page2[PG.ANNOTS]):
                 a = a.get_object()
-                aa = a.clone(pdf, ignore_fields=("/P", "/StructParent"))
+                aa = a.clone(
+                    pdf,
+                    ignore_fields=("/P", "/StructParent", "/Parent"),
+                    force_duplicate=True,
+                )
                 r = cast(ArrayObject, a["/Rect"])
                 pt1 = trsf.apply_on((r[0], r[1]), True)
                 pt2 = trsf.apply_on((r[2], r[3]), True)
@@ -955,6 +959,10 @@ class PageObject(DictionaryObject):
                         + cast(tuple, trsf.apply_on((q[4], q[5]), True))
                         + cast(tuple, trsf.apply_on((q[6], q[7]), True))
                     )
+                try:
+                    aa["/Popup"][NameObject("/Parent")] = aa.indirect_reference
+                except KeyError:
+                    pass
                 try:
                     aa[NameObject("/P")] = self.indirect_reference
                     annots.append(aa.indirect_reference)
@@ -1892,9 +1900,9 @@ class PageObject(DictionaryObject):
                         elif (
                             abs(delta_y) < f * 0.3
                             and abs(delta_x) > current_spacewidth() * f * 15
+                            and (output + text)[-1] != " "
                         ):
-                            if (output + text)[-1] != " ":
-                                text += " "
+                            text += " "
                     elif orientation == 180:
                         if delta_y > 0.8 * f:
                             if (output + text)[-1] != "\n":
@@ -1911,9 +1919,9 @@ class PageObject(DictionaryObject):
                         elif (
                             abs(delta_y) < f * 0.3
                             and abs(delta_x) > current_spacewidth() * f * 15
+                            and (output + text)[-1] != " "
                         ):
-                            if (output + text)[-1] != " ":
-                                text += " "
+                            text += " "
                     elif orientation == 90:
                         if delta_x > 0.8 * f:
                             if (output + text)[-1] != "\n":
@@ -1930,9 +1938,9 @@ class PageObject(DictionaryObject):
                         elif (
                             abs(delta_x) < f * 0.3
                             and abs(delta_y) > current_spacewidth() * f * 15
+                            and (output + text)[-1] != " "
                         ):
-                            if (output + text)[-1] != " ":
-                                text += " "
+                            text += " "
                     elif orientation == 270:
                         if delta_x < -0.8 * f:
                             if (output + text)[-1] != "\n":
@@ -1949,9 +1957,9 @@ class PageObject(DictionaryObject):
                         elif (
                             abs(delta_x) < f * 0.3
                             and abs(delta_y) > current_spacewidth() * f * 15
+                            and (output + text)[-1] != " "
                         ):
-                            if (output + text)[-1] != " ":
-                                text += " "
+                            text += " "
                 except Exception:
                     pass
 
@@ -1974,13 +1982,12 @@ class PageObject(DictionaryObject):
                 for op in operands[0]:
                     if isinstance(op, (str, bytes)):
                         process_operation(b"Tj", [op])
-                    if isinstance(op, (int, float, NumberObject, FloatObject)):
-                        if (
-                            (abs(float(op)) >= _space_width)
-                            and (len(text) > 0)
-                            and (text[-1] != " ")
-                        ):
-                            process_operation(b"Tj", [" "])
+                    if isinstance(op, (int, float, NumberObject, FloatObject)) and (
+                        (abs(float(op)) >= _space_width)
+                        and (len(text) > 0)
+                        and (text[-1] != " ")
+                    ):
+                        process_operation(b"Tj", [" "])
             elif operator == b"Do":
                 output += text
                 if visitor_text is not None:
@@ -2048,7 +2055,7 @@ class PageObject(DictionaryObject):
         see function set_custom_rtl
 
         Additionally you can provide visitor-methods to get informed on all
-        operands and all text-objects.
+        operations and all text-objects.
         For example in some PDF files this can be useful to parse tables.
 
         Args:
@@ -2060,11 +2067,11 @@ class PageObject(DictionaryObject):
                 270 (turned Right)
             space_width: force default space width
                 if not extracted from font (default: 200)
-            visitor_operand_before: function to be called before processing an operand.
-                It has four arguments: operand, operand-arguments,
+            visitor_operand_before: function to be called before processing an operation.
+                It has four arguments: operator, operand-arguments,
                 current transformation matrix and text matrix.
-            visitor_operand_after: function to be called after processing an operand.
-                It has four arguments: operand, operand-arguments,
+            visitor_operand_after: function to be called after processing an operation.
+                It has four arguments: operator, operand-arguments,
                 current transformation matrix and text matrix.
             visitor_text: function to be called when extracting some text at some position.
                 It has five arguments: text, current transformation matrix,
@@ -2377,11 +2384,11 @@ def _get_fonts_walk(
     fontkeys = ("/FontFile", "/FontFile2", "/FontFile3")
     if "/BaseFont" in obj:
         fnt.add(cast(str, obj["/BaseFont"]))
-    if "/FontName" in obj:
-        if [x for x in fontkeys if x in obj]:  # test to see if there is FontFile
-            emb.add(cast(str, obj["/FontName"]))
+    if "/FontName" in obj and [x for x in fontkeys if x in obj]:
+        # the list comprehension ensures there is FontFile
+        emb.add(cast(str, obj["/FontName"]))
 
-    for key in obj.keys():
+    for key in obj:
         _get_fonts_walk(cast(DictionaryObject, obj[key]), fnt, emb)
 
     return fnt, emb  # return the sets for each page
