@@ -67,10 +67,13 @@ from ._utils import (
 )
 from .constants import CatalogAttributes as CA
 from .constants import CatalogDictionary as CD
-from .constants import CheckboxRadioButtonAttributes
+from .constants import (
+    CheckboxRadioButtonAttributes,
+    FieldDictionaryAttributes,
+    GoToActionArguments,
+)
 from .constants import Core as CO
 from .constants import DocumentInformationAttributes as DI
-from .constants import FieldDictionaryAttributes, GoToActionArguments
 from .constants import PageAttributes as PG
 from .constants import PagesAttributes as PA
 from .constants import TrailerKeys as TK
@@ -342,9 +345,8 @@ class PdfReader:
                 # raise if password provided
                 raise WrongPasswordError("Wrong password")
             self._override_encryption = False
-        else:
-            if password is not None:
-                raise PdfReadError("Not encrypted file")
+        elif password is not None:
+            raise PdfReadError("Not encrypted file")
 
     @property
     def pdf_header(self) -> str:
@@ -433,8 +435,6 @@ class PdfReader:
         """
         Calculate the number of pages in this PDF file.
 
-        Args:
-
         Returns:
             The number of pages of the parsed PDF file
 
@@ -1437,7 +1437,7 @@ class PdfReader:
         stream.seek(-1, 1)
 
         # although it's not used, it might still be necessary to read
-        _obj = stream.read(3)  # noqa: F841
+        _obj = stream.read(3)
 
         read_non_whitespace(stream)
         stream.seek(-1, 1)
@@ -1522,7 +1522,7 @@ class PdfReader:
                     continue
                 xref_k = sorted(
                     xref_entry.keys()
-                )  # must ensure ascendant to prevent damange
+                )  # must ensure ascendant to prevent damage
                 for id in xref_k:
                     stream.seek(xref_entry[id], 0)
                     try:
@@ -1600,10 +1600,10 @@ class PdfReader:
             raise PdfReadError("xref table read error")
         read_non_whitespace(stream)
         stream.seek(-1, 1)
-        firsttime = True  # check if the first time looking at the xref table
+        first_time = True  # check if the first time looking at the xref table
         while True:
             num = cast(int, read_object(stream, self))
-            if firsttime and num != 0:
+            if first_time and num != 0:
                 self.xref_index = num
                 if self.strict:
                     logger_warning(
@@ -1612,7 +1612,7 @@ class PdfReader:
                     )
                     # if table not zero indexed, could be due to error from when PDF was created
                     # which will lead to mismatched indices later on, only warned and corrected if self.strict==True
-            firsttime = False
+            first_time = False
             read_non_whitespace(stream)
             stream.seek(-1, 1)
             size = cast(int, read_object(stream, self))
@@ -1647,7 +1647,7 @@ class PdfReader:
 
                     offset, generation = int(offset_b), int(generation_b)
                 except Exception:
-                    # if something wrong occured
+                    # if something wrong occurred
                     if hasattr(stream, "getbuffer"):
                         buf = bytes(stream.getbuffer())  # type: ignore
                     else:
@@ -1695,8 +1695,8 @@ class PdfReader:
                 num += 1
             read_non_whitespace(stream)
             stream.seek(-1, 1)
-            trailertag = stream.read(7)
-            if trailertag != b"trailer":
+            trailer_tag = stream.read(7)
+            if trailer_tag != b"trailer":
                 # more xrefs!
                 stream.seek(-7, 1)
             else:
@@ -2105,7 +2105,7 @@ class PdfReader:
         interim[NameObject("/Kids")] = acroform[NameObject("/Fields")]
         self.cache_indirect_object(
             0,
-            max([i for (g, i) in self.resolved_objects.keys() if g == 0]) + 1,
+            max([i for (g, i) in self.resolved_objects if g == 0]) + 1,
             interim,
         )
         arr = ArrayObject()
