@@ -38,16 +38,7 @@ import math
 import struct
 import zlib
 from io import BytesIO
-from typing import Any, Dict, Optional, Tuple, Union, cast
-
-from .generic import ArrayObject, DictionaryObject, IndirectObject, NameObject
-
-try:
-    from typing import Literal  # type: ignore[attr-defined]
-except ImportError:
-    # PEP 586 introduced typing.Literal with Python 3.8
-    # For older Python versions, the backport typing_extensions is necessary:
-    from typing_extensions import Literal  # type: ignore[misc]
+from typing import TYPE_CHECKING, Any, Dict, Optional, Tuple, Union, cast
 
 from ._utils import b_, deprecate_with_replacement, ord_, paeth_predictor
 from .constants import CcittFaxDecodeParameters as CCITT
@@ -59,6 +50,15 @@ from .constants import ImageAttributes as IA
 from .constants import LzwFilterParameters as LZW
 from .constants import StreamAttributes as SA
 from .errors import PdfReadError, PdfStreamError
+from .generic import ArrayObject, DictionaryObject, IndirectObject, NameObject
+
+if TYPE_CHECKING:
+    try:
+        from typing import Literal  # type: ignore[attr-defined]
+    except ImportError:
+        # PEP 586 introduced typing.Literal with Python 3.8
+        # For older Python versions, the backport typing_extensions is necessary:
+        from typing_extensions import Literal  # type: ignore[misc]
 
 
 def decompress(data: bytes) -> bytes:
@@ -202,7 +202,7 @@ class ASCIIHexDecode:
     @staticmethod
     def decode(
         data: str,
-        decode_parms: Union[None, ArrayObject, DictionaryObject] = None,  # noqa: F841
+        decode_parms: Union[None, ArrayObject, DictionaryObject] = None,
         **kwargs: Any,
     ) -> str:
         """
